@@ -95,6 +95,8 @@ class EarlyStoppingCallback(Callback):
             self.start_time = time.time()
 
     def on_trial_end(self, hyper_model, space, trial_no, reward, improved, elapsed):
+        reward = reward[0]  # NOTE only use first metric
+
         if self.start_time is None:
             self.start_time = time.time()
 
@@ -169,6 +171,7 @@ class FileLoggingCallback(Callback):
         #     f.write(space.params_summary())
 
     def on_trial_end(self, hyper_model, space, trial_no, reward, improved, elapsed):
+        reward = reward[0]
         with self.open(f'{self.output_dir}/trial_{improved}_{trial_no:04d}_{reward:010.8f}_{elapsed:06.2f}.log',
                        'w') as f:
             f.write(space.params_summary())
@@ -191,8 +194,9 @@ class FileLoggingCallback(Callback):
                 f.write('\r\n---------------------------------------------------\r\n\r\n')
 
     def on_skip_trial(self, hyper_model, space, trial_no, reason, reward, improved, elapsed):
+        reward_repr = "_".join(list(map(lambda v: f"{v:010.8f}", reward)))
         with self.open(
-                f'{self.output_dir}/trial_{reason}_{improved}_{trial_no:04d}_{reward:010.8f}_{elapsed:06.2f}.log',
+                f'{self.output_dir}/trial_{reason}_{improved}_{trial_no:04d}_{reward_repr}_{elapsed:06.2f}.log',
                 'w') as f:
             f.write(space.params_summary())
 
@@ -340,11 +344,12 @@ class NotebookCallback(Callback):
             update_display(df_best_trials, display_id=self.current_trial_display_id)
 
     def on_trial_end(self, hyper_model, space, trial_no, reward, improved, elapsed):
+        reward = reward[0]
         self.last_trial_no = trial_no
         self.last_reward = reward
 
         best_trial = hyper_model.get_best_trial()
-        if best_trial is not None and self.best_trial_display_id is not None:
+        if best_trial is not None and not isinstance(best_trial, list) and self.best_trial_display_id is not None:
             update_display(best_trial.space_sample, display_id=self.best_trial_display_id)
 
     def on_trial_error(self, hyper_model, space, trial_no):
@@ -363,15 +368,29 @@ class ProgressiveCallback(Callback):
         self.pbar = tqdm(total=max_trials, leave=False, desc='search')
 
     def on_search_end(self, hyper_model):
-        self.pbar.update(self.pbar.total)
-        self.pbar.close()
-        self.pbar = None
+        if self.pbar is not None:
+            self.pbar.update(self.pbar.total)
+            self.pbar.close()
+            self.pbar = None
 
     def on_search_error(self, hyper_model):
         self.on_search_end(hyper_model)
 
     def on_trial_end(self, hyper_model, space, trial_no, reward, improved, elapsed):
-        self.pbar.update(1)
+        if self.pbar is not None:
+            self.pbar.update(1)
 
     def on_trial_error(self, hyper_model, space, trial_no):
-        self.pbar.update(1)
+        if self.pbar is not None:
+            self.pbar.update(1)
+
+    def __getstate__(self):
+        try:
+            state = super().__getstate__()
+        except AttributeError:
+            state = self.__dict__
+
+        state = state.copy()
+        state['pbar'] = None
+
+        return state
