@@ -7,16 +7,30 @@ import os
 import pickle
 import shutil
 from collections import OrderedDict
+from typing import List
 
 import numpy as np
 import pandas as pd
 
 from hypernets.utils.common import isnotebook, to_repr
 from ..core.searcher import OptimizeDirection
+from ..core import pareto
+
+
+def _is_bigdata(v):
+    big_data_types = (pd.Series, pd.DataFrame, np.ndarray)
+    if isinstance(v, big_data_types):
+        return True
+
+    type_name = type(v).__name__.lower()
+    if any(type_name.find(s) for s in ('array', 'dataframe', 'series')):
+        return True
+
+    return False
 
 
 class Trial():
-    def __init__(self, space_sample, trial_no, reward, elapsed, model_file=None, succeeded=True):
+    def __init__(self, space_sample, trial_no, reward=None, elapsed=None, model_file=None, succeeded=True):
         self.space_sample = space_sample
         self.trial_no = trial_no
         self.reward = reward
@@ -26,6 +40,7 @@ class Trial():
 
         self.memo = {}
         self.iteration_scores = {}
+        self.context = None
 
     def __repr__(self):
         return to_repr(self)
@@ -81,10 +96,9 @@ class Trial():
 
         # state = {k: v for k, v in state.items() if k != 'memo'}
         memo = state.get('memo', None)
-        big_data_types = (pd.Series, pd.DataFrame, np.ndarray)
-        big_data_exists = isinstance(memo, dict) and any(isinstance(v, big_data_types) for v in memo.values())
+        big_data_exists = isinstance(memo, dict) and any(_is_bigdata(v) for v in memo.values())
         if big_data_exists:
-            compacted_memo = {k: v for k, v in memo.items() if not isinstance(v, big_data_types)}
+            compacted_memo = {k: v for k, v in memo.items() if not _is_bigdata(v)}
             state = state.copy()
             state['memo'] = compacted_memo
 
@@ -371,6 +385,85 @@ class TrialHistory():
             return chart.render(output)
 
 
+class DominateBasedTrialHistory(TrialHistory):
+
+    def __init__(self, directions, objective_names):
+        super(DominateBasedTrialHistory, self).__init__(optimize_direction=directions[0])
+
+        self.directions = directions
+        self.objective_names = objective_names
+
+    def get_best(self):
+        succeed_trials = list(filter(lambda t: t.succeeded, self.trials))
+        solutions = np.asarray([t.reward for t in succeed_trials])
+        optimal_inx = pareto.calc_nondominated_set(solutions=solutions, directions=self.directions)
+        return [succeed_trials[i] for i in optimal_inx]
+
+    def append(self, trial):
+        self.trials.append(trial)
+        return trial in self.get_best()
+
+    def to_df(self, include_params=False):
+        if len(self.trials) > 0:
+            df = super(DominateBasedTrialHistory, self).to_df(include_params=include_params)
+            ns = self.get_best()
+
+            df['non_dominated'] = [t in ns for t in self.trials]
+            df['model_index'] = [ns.index(t) if t in ns else None for t in self.trials]
+
+            scores: np.ndarray = np.array(df['reward'].values.tolist())
+            assert scores.shape[1] == len(self.objective_names)
+            for i, name in enumerate(self.objective_names):
+                df[f'reward_{name}'] = scores[:, i]
+        else:
+            df = pd.DataFrame()
+
+        return df
+
+    def plot_best_trials(self, index=True, figsize=(5, 5), loc=None, bbox_to_anchor=None, xlim=None, ylim=None):
+        try:
+            from matplotlib import pyplot as plt
+        except Exception:
+            raise RuntimeError("it requires matplotlib installed.")
+
+        if len(self.objective_names) != 2:
+            raise RuntimeError("plot currently works only in case of 2 objectives. ")
+
+        best_trials = self.get_best()
+        objective_names = self.objective_names
+
+        fig = plt.figure(figsize=figsize)
+        ax = fig.add_subplot()
+
+        comparison = list(filter(lambda v: v not in best_trials, self.trials))
+
+        if len(comparison) > 0:
+            comp_scores = np.array([t.reward for t in comparison])
+            ax.scatter(comp_scores[:, 0], comp_scores[:, 1], c='blue', label='dominated', marker='o')
+
+        if len(best_trials) > 0:
+            best_scores = np.array([t.reward for t in best_trials])
+            ax.scatter(best_scores[:, 0], best_scores[:, 1], c='red', label='non-dominated', marker='o')
+            best_scores_sorted = np.array(sorted(best_scores, key=lambda v: v[1]))
+            # non-dominated does not mean optimal
+            ax.plot(best_scores_sorted[:, 0], best_scores_sorted[:, 1], color='c')
+
+        if index:
+            for i, t in enumerate(best_trials):
+                ax.text(t.reward[0], t.reward[1], f"{i}", ha='center', va='bottom', fontsize=9)
+
+        if xlim:
+            ax.set_xlim(*xlim)
+        if ylim:
+            ax.set_ylim(*ylim)
+
+        ax.legend(loc=loc, bbox_to_anchor=bbox_to_anchor)
+        plt.xlabel(objective_names[0])
+        plt.ylabel(objective_names[1])
+        plt.title(f"Best trials in TrialHistory(total={len(self.trials)})")
+        return fig, ax
+
+
 class TrialStore(object):
     def __init__(self):
         self.reset()
