@@ -5,7 +5,8 @@ from .cfg import DispatchCfg as c
 from ..core.callbacks import EarlyStoppingError
 from ..core.dispatcher import Dispatcher
 from ..core.trial import Trial
-from ..utils import logging, fs
+from ..tabular import get_tool_box
+from ..utils import logging, fs, const
 
 logger = logging.get_logger(__name__)
 
@@ -17,17 +18,28 @@ class InProcessDispatcher(Dispatcher):
         self.models_dir = models_dir
         fs.makedirs(models_dir, exist_ok=True)
 
-    def dispatch(self, hyper_model, X, y, X_eval, y_eval, cv, num_folds, max_trials, dataset_id, trial_store,
+    def dispatch(self, hyper_model, X, y, X_eval, y_eval, X_test, cv, num_folds, max_trials, dataset_id, trial_store,
                  **fit_kwargs):
         retry_limit = c.trial_retry_limit
 
         trial_no = 1
         retry_counter = 0
 
+        space_options = {}
+        if hyper_model.searcher.kind() == const.SEARCHER_MOO:
+            if 'feature_usage' in [_.name for _ in hyper_model.searcher.objectives]:
+                tb = get_tool_box(X, y)
+                preprocessor = tb.general_preprocessor(X)
+                estimator = tb.general_estimator(X, y, task=hyper_model.task)
+                estimator.fit(preprocessor.fit_transform(X, y), y)
+                importances = list(zip(estimator.feature_name_, estimator.feature_importances_))
+                space_options['importances'] = importances
+
         while trial_no <= max_trials:
             gc.collect()
             try:
-                space_sample = hyper_model.searcher.sample()
+
+                space_sample = hyper_model.searcher.sample(space_options=space_options)
                 if hyper_model.history.is_existed(space_sample):
                     if retry_counter >= retry_limit:
                         logger.info(f'Unable to take valid sample and exceed the retry limit {retry_limit}.')
@@ -80,7 +92,7 @@ class InProcessDispatcher(Dispatcher):
 
                 model_file = '%s/%05d_%s.pkl' % (self.models_dir, trial_no, space_sample.space_id)
 
-                trial = hyper_model._run_trial(space_sample, trial_no, X, y, X_eval, y_eval, cv, num_folds, model_file,
+                trial = hyper_model._run_trial(space_sample, trial_no, X, y, X_eval, y_eval, X_test, cv, num_folds, model_file,
                                                **fit_kwargs)
 
                 if trial.succeeded:
