@@ -8,6 +8,7 @@ from hypernets.discriminators import make_discriminator
 from hypernets.experiment import CompeteExperiment
 from hypernets.experiment.cfg import ExperimentCfg as cfg
 from hypernets.model import HyperModel
+from hypernets.model.objectives import create_objective
 from hypernets.searchers import make_searcher, PlaybackSearcher
 from hypernets.tabular import get_tool_box
 from hypernets.tabular.cache import clear as _clear_cache
@@ -38,14 +39,24 @@ def default_search_callbacks():
     return cbs
 
 
-def to_search_object(search_space, optimize_direction, searcher, searcher_options):
+def to_objective_object(o, force_minimize=False, **kwargs):
+    from hypernets.core.objective import Objective
+
+    if isinstance(o, str):
+        return create_objective(o, force_minimize=force_minimize, **kwargs)
+    elif isinstance(o, Objective):
+        return o
+    else:
+        raise RuntimeError("objective specific should be instanced by 'Objective' or a string")
+
+
+def to_search_object(search_space, optimize_direction, searcher, searcher_options,
+                     reward_metric=None, scorer=None, objectives=None,  task=None, pos_label=None):
+
     def to_searcher(cls, options):
         assert search_space is not None, '"search_space" should be specified if "searcher" is None or str.'
         assert optimize_direction in {'max', 'min'}
-        if options is None:
-            options = {}
-        options['optimize_direction'] = optimize_direction
-        s = make_searcher(cls, search_space, **options)
+        s = make_searcher(cls, search_space, optimize_direction=optimize_direction, **options)
 
         return s
 
@@ -53,6 +64,28 @@ def to_search_object(search_space, optimize_direction, searcher, searcher_option
         from hypernets.searchers import EvolutionSearcher
         sch = to_searcher(EvolutionSearcher, searcher_options)
     elif isinstance(searcher, (type, str)):
+        from hypernets.searchers.moo import MOOSearcher
+        from hypernets.searchers import get_searcher_cls
+
+        search_cls = get_searcher_cls(searcher)
+        if issubclass(search_cls, MOOSearcher):
+            from hypernets.model.objectives import PredictionObjective
+            from hypernets.searchers.moead_searcher import MOEADSearcher
+            from hypernets.core import get_random_state
+
+            if objectives is None:
+                objectives = ['nf']
+            objectives_instance = []
+            force_minimize = (search_cls == MOEADSearcher)
+            for o in objectives:
+                objectives_instance.append(to_objective_object(o, force_minimize=force_minimize,
+                                                               task=task, pos_label=pos_label))
+
+            objectives_instance.insert(0, PredictionObjective.create(reward_metric, force_minimize=force_minimize,
+                                                                     task=task, pos_label=pos_label))
+            searcher_options['objectives'] = objectives_instance
+            searcher_options['random_state'] = get_random_state()
+
         sch = to_searcher(searcher, searcher_options)
     else:
         from hypernets.core.searcher import Searcher as SearcherSpec
@@ -90,6 +123,7 @@ def make_experiment(hyper_model_cls,
                     early_stopping_time_limit=3600,
                     early_stopping_reward=None,
                     reward_metric=None,
+                    objectives=None,
                     optimize_direction=None,
                     hyper_model_options=None,
                     discriminator=None,
@@ -129,9 +163,10 @@ def make_experiment(hyper_model_cls,
         ExperimentCallback list.
     searcher : str, searcher class, search object, optional
         The hypernets Searcher instance to explore search space, default is EvolutionSearcher instance.
-        For str, should be one of 'evolution', 'mcts', 'random'.
-        For class, should be one of EvolutionSearcher, MCTSSearcher, RandomSearcher, or subclass of hypernets Searcher.
-        For other, should be instance of hypernets Searcher.
+        For str, should be one of 'evolution', 'mcts', 'random', 'nsga2', 'moead'.  # TODO rnsga
+        For class, should be one of EvolutionSearcher, MCTSSearcher, RandomSearcher, MOEADSearcher, NSGAIISearrcher
+         or subclass of hypernets Searcher.
+        For other, should be instanced of hypernets Searcher.
     searcher_options: dict, optional, default is None
         The options to create searcher, is used if searcher is str.
     search_space : callable, optional
@@ -162,6 +197,13 @@ def make_experiment(hyper_model_cls,
             - rmse
             - r2
             - recall
+    objectives : List[Union[Objective, str]] optional, (default to ['nf'] )
+        Used for multi-objectives optimization, "reward_metric" is alway picked as the first objective, specilly for
+        "MOEADSearcher", will force the indicator to be the smaller the better by converting score to a negative number.
+        For str as identifier of objectives, possible values:
+            - elapsed
+            - pred_perf
+            - nf
     optimize_direction : str, optional
         Hypernets search reward metric direction, default is detected from reward_metric.
     discriminator : instance of hypernets.discriminator.BaseDiscriminator, optional
@@ -170,7 +212,7 @@ def make_experiment(hyper_model_cls,
         Options to initlize HyperModel except *reward_metric*, *task*, *callbacks*, *discriminator*.
     evaluation_metrics: str, list, or None (default='auto'),
         If *eval_data* is not None, it used to evaluate model with the metrics.
-        For str should be 'auto', it will selected metrics accord to machine learning task type.
+        For str should be 'auto', it will select metrics accord to machine learning task type.
         For list should be metrics name.
     evaluation_persist_prediction: bool (default=False)
     evaluation_persist_prediction_dir: str or None (default='predction')
@@ -178,7 +220,7 @@ def make_experiment(hyper_model_cls,
     report_render: str, obj, optional, default is None
         The experiment report render.
         For str should be one of 'excel'
-        for obj should be instance ReportRender
+        for obj should be instanced of ReportRender
     report_render_options: dict, optional
         The options to create render, is used if render is str.
     experiment_cls: class, or None, (default=CompeteExperiment)
@@ -284,7 +326,16 @@ def make_experiment(hyper_model_cls,
     if optimize_direction is None or len(optimize_direction) == 0:
         optimize_direction = 'max' if scorer._sign > 0 else 'min'
 
-    searcher = to_search_object(search_space, optimize_direction, searcher, searcher_options)
+    if searcher_options is None:
+        searcher_options = {}
+
+    searcher = to_search_object(search_space, optimize_direction, searcher, searcher_options,
+                                reward_metric=reward_metric, scorer=scorer, objectives=objectives, task=task,
+                                pos_label=kwargs.get('pos_label'))
+
+    if searcher.kind() == const.SEARCHER_MOO:
+        if 'psi' in [_.name for _ in searcher.objectives]:
+            assert X_test is not None, "psi objective requires test dataset"
 
     if cfg.experiment_auto_down_sample_enabled and not isinstance(searcher, PlaybackSearcher) \
             and 'down_sample_search' not in kwargs.keys():
@@ -301,7 +352,8 @@ def make_experiment(hyper_model_cls,
 
     if eval_data is not None:
         from hypernets.experiment import MLEvaluateCallback
-        if task in [const.TASK_REGRESSION, const.TASK_BINARY, const.TASK_MULTICLASS]:
+        if task in [const.TASK_REGRESSION, const.TASK_BINARY, const.TASK_MULTICLASS]\
+                and searcher.kind() == const.SEARCHER_SOO:
             if evaluation_persist_prediction is True:
                 persist_dir = evaluation_persist_prediction_dir
             else:
