@@ -86,6 +86,7 @@ class StepNames:
     FINAL_SEARCHING = 'two_stage_searching'
     FINAL_ENSEMBLE = 'final_ensemble'
     FINAL_TRAINING = 'final_train'
+    FINAL_MOO = 'final_moo'
 
 
 class ExperimentStep(BaseEstimator):
@@ -151,6 +152,7 @@ class ExperimentStep(BaseEstimator):
         state = super().__getstate__()
         # Don't pickle experiment
         if 'experiment' in state.keys():
+            state = state.copy()
             state['experiment'] = None
         return state
 
@@ -996,12 +998,22 @@ class SpaceSearchStep(ExperimentStep):
                                 X_eval=X_eval.copy() if X_eval is not None else None,
                                 y_eval=y_eval.copy() if y_eval is not None else None,
                                 dataset_id=dataset_id, **kwargs)
-            if model.get_best_trial() is None or model.get_best_trial().reward == 0:
+            best_trial = model.get_best_trial()
+
+            if best_trial is None:
                 raise RuntimeError('Not found available trial, change experiment settings and try again pls.')
+            else:
+                if not isinstance(best_trial, list) and best_trial.reward == 0:
+                    raise RuntimeError('Not found available trial, change experiment settings and try again pls.')
+            if isinstance(best_trial, list):
+                best_reward = [t.reward for t in best_trial]
+            else:
+                best_reward = best_trial.reward
+
             self.dataset_id = dataset_id
             self.model = model
             self.history_ = model.history
-            self.best_reward_ = model.get_best_trial().reward
+            self.best_reward_ = best_reward
         else:
             logger.info(f'reuse fitted step: {fitted_step.name}')
             self.status_ = self.STATUS_SKIPPED
@@ -1018,7 +1030,7 @@ class SpaceSearchStep(ExperimentStep):
         es = self.find_early_stopping_callback(model.callbacks)
         if es is not None and es.time_limit is not None and es.time_limit > 0:
             es.time_limit = self.estimate_time_limit(es.time_limit)
-        model.search(X_train, y_train, X_eval, y_eval, cv=self.cv, num_folds=self.num_folds, **kwargs)
+        model.search(X_train, y_train, X_eval, y_eval, X_test=X_test, cv=self.cv, num_folds=self.num_folds, **kwargs)
         return model
 
     def from_fitted_step(self, fitted_step):
@@ -1260,7 +1272,7 @@ class EnsembleStep(EstimatorBuilderStep):
 
     def select_trials(self, hyper_model):
         """
-        select trails to ensemble from hyper_model (and it's history)
+        select trials to ensemble from hyper_model (and it's history)
         """
         best_trials = hyper_model.get_top_trials(self.ensemble_size)
         return best_trials
@@ -1344,6 +1356,21 @@ class FinalTrainStep(EstimatorBuilderStep):
         return estimator
 
 
+class MOOFinalStep(EstimatorBuilderStep):
+
+    def __init__(self, experiment, name):
+        super().__init__(experiment, name)
+
+    def build_estimator(self, hyper_model, X_train, y_train, X_test=None, X_eval=None, y_eval=None, **kwargs):
+        # get the estimator that corresponding non-dominated solution
+        estimators = []
+        for t in hyper_model.history.get_best():
+            estimators.append(hyper_model.load_estimator(t.model_file))
+
+        logger.info(f"best trails are: {estimators}")
+        return estimators
+
+
 class PseudoLabelStep(ExperimentStep):
     def __init__(self, experiment, name, estimator_builder_name,
                  strategy=None, proba_threshold=None, proba_quantile=None, sample_number=None,
@@ -1504,6 +1531,10 @@ class SteppedExperiment(Experiment):
         self.hyper_model_ = None
 
     def train(self, hyper_model, X_train, y_train, X_test, X_eval=None, y_eval=None, **kwargs):
+        tb = get_tool_box(X_train, y_train, X_test, X_eval, y_eval)
+        if tb.__name__.lower().find('dask') >= 0:
+            tb.dump_cluster_info()
+
         from_step = self.get_step_index(kwargs.pop('from_step', None), 0)
         to_step = self.get_step_index(kwargs.pop('to_step', None), len(self.steps) - 1)
         assert from_step <= to_step
@@ -1603,8 +1634,17 @@ class SteppedExperiment(Experiment):
 
         if len(pipeline_steps) > 0:
             tb = get_tool_box(X_train, y_train, X_test, X_eval, y_eval)
-            pipeline_steps += [('estimator', last_step.estimator_)]
-            estimator = tb.transformers['Pipeline'](pipeline_steps)
+            last_estimator = last_step.estimator_
+            if isinstance(last_estimator, list):
+                pipelines = []
+                for item in last_estimator:
+                    pipeline_model = tb.transformers['Pipeline'](pipeline_steps + [('estimator', item)])
+                    pipelines.append(pipeline_model)
+                estimator = pipelines
+            else:
+                pipeline_steps += [('estimator', last_step.estimator_)]
+                estimator = tb.transformers['Pipeline'](pipeline_steps)
+
             if logger.is_info_enabled():
                 names = [step[0] for step in pipeline_steps]
                 logger.info(f'trained experiment pipeline: {names}')
@@ -1855,7 +1895,8 @@ class CompeteExperiment(SteppedExperiment):
 
         if feature_generation:
             if 'FeatureGenerationTransformer' not in tb.transformers.keys():
-                raise NotImplementedError('feature_generation is not supported for your data')
+                raise ValueError('feature_generation is not supported for your data, '
+                                 'or "featuretools" is not installed.')
 
             if data_cleaner_args is None:
                 data_cleaner_args = {}
@@ -1997,12 +2038,16 @@ class CompeteExperiment(SteppedExperiment):
                                      cv=cv, num_folds=num_folds))
 
         # final train
-        if ensemble_size is not None and ensemble_size > 1:
-            creator = creators[StepNames.FINAL_ENSEMBLE]
-            last_step = creator(self, StepNames.FINAL_ENSEMBLE, scorer=scorer, ensemble_size=ensemble_size)
+        if hyper_model.searcher.kind() == const.SEARCHER_MOO:
+            creator = creators[StepNames.FINAL_MOO]
+            last_step = creator(self, StepNames.FINAL_MOO)
         else:
-            creator = creators[StepNames.FINAL_TRAINING]
-            last_step = creator(self, StepNames.FINAL_TRAINING, retrain_on_wholedata=retrain_on_wholedata)
+            if ensemble_size is not None and ensemble_size > 1:
+                creator = creators[StepNames.FINAL_ENSEMBLE]
+                last_step = creator(self, StepNames.FINAL_ENSEMBLE, scorer=scorer, ensemble_size=ensemble_size)
+            else:
+                creator = creators[StepNames.FINAL_TRAINING]
+                last_step = creator(self, StepNames.FINAL_TRAINING, retrain_on_wholedata=retrain_on_wholedata)
         steps.append(last_step)
 
         # ignore warnings
@@ -2015,6 +2060,9 @@ class CompeteExperiment(SteppedExperiment):
         self.run_kwargs = kwargs
 
         self.evaluation_ = None
+
+        hyper_model.context.put("exp", self)
+
         super(CompeteExperiment, self).__init__(steps,
                                                 hyper_model, X_train, y_train, X_eval=X_eval, y_eval=y_eval,
                                                 X_test=X_test, eval_size=eval_size, task=task,
@@ -2040,6 +2088,7 @@ class CompeteExperiment(SteppedExperiment):
             StepNames.FINAL_SEARCHING: SpaceSearchWithDownSampleStep if down_sample_search else SpaceSearchStep,
             StepNames.FINAL_ENSEMBLE: EnsembleStep,
             StepNames.FINAL_TRAINING: FinalTrainStep,
+            StepNames.FINAL_MOO: MOOFinalStep,
         }
 
         tb = get_tool_box(X_train, y_train, X_test, X_eval, y_eval)
