@@ -6,8 +6,9 @@ import time
 import traceback
 from collections import UserDict
 
+from ..core.context import DefaultContext
 from ..core.meta_learner import MetaLearner
-from ..core.trial import Trial, TrialHistory, DiskTrialStore
+from ..core.trial import Trial, TrialHistory, DiskTrialStore, DominateBasedTrialHistory
 from ..discriminators import UnPromisingTrial
 from ..dispatchers import get_dispatcher
 from ..tabular import get_tool_box
@@ -30,21 +31,38 @@ class HyperModel:
         self.dispatcher = dispatcher
         self.callbacks = callbacks if callbacks is not None else []
         self.reward_metric = reward_metric
-        self.history = TrialHistory(searcher.optimize_direction)
+
+        searcher_type = searcher.kind()
+
+        if searcher_type == const.SEARCHER_MOO:
+            objective_names = [_.name for _ in searcher.objectives]
+            directions = [_.direction for _ in searcher.objectives]
+            self.history = DominateBasedTrialHistory(directions=directions, objective_names=objective_names)
+        else:
+            self.history = TrialHistory(searcher.optimize_direction)
+
         self.task = task
         self.discriminator = discriminator
         if self.discriminator:
             self.discriminator.bind_history(self.history)
 
+        self.context = DefaultContext()
+
     def _get_estimator(self, space_sample):
         raise NotImplementedError
 
+    @property
+    def reward_metrics(self):
+        if isinstance(self.reward_metric, list):
+            return self.reward_metric
+        else:
+            return [self.reward_metric]
+
     def load_estimator(self, model_file):
         raise NotImplementedError
 
-    def _run_trial(self, space_sample, trial_no, X, y, X_eval, y_eval, cv=False, num_folds=3, model_file=None,
-                   **fit_kwargs):
-
+    def _run_trial(self, space_sample, trial_no, X, y, X_eval, y_eval, X_test=None, cv=False, num_folds=3,
+                   model_file=None, **fit_kwargs):
         start_time = time.time()
         estimator = self._get_estimator(space_sample)
         if self.discriminator:
@@ -59,21 +77,23 @@ class HyperModel:
         metrics = fit_kwargs.pop('metrics') if 'metrics' in fit_kwargs else None
         if metrics is not None:
             assert isinstance(metrics, (tuple, list)), 'metrics should be list or tuple'
-            if not any(map(lambda _: _ is self.reward_metric, metrics)):
-                metrics = list(metrics) + [self.reward_metric]
+            metrics = list(set(list(metrics)).union(set(self.reward_metrics)))
         else:
-            metrics = [self.reward_metric]
+            metrics = self.reward_metrics
 
         succeeded = False
         scores = None
         oof = None
         oof_scores = None
+        x_vals = None
+        y_vals = None
+        X_trains = None
+        y_trains = None
         try:
             if cv:
-                scores, oof, oof_scores = estimator.fit_cross_validation(X, y, stratified=True, num_folds=num_folds,
-                                                                         shuffle=False, random_state=9527,
-                                                                         metrics=metrics,
-                                                                         **fit_kwargs)
+                 ret_data = estimator.fit_cross_validation(X, y, stratified=True, num_folds=num_folds, shuffle=False,
+                                                           random_state=9527, metrics=metrics, **fit_kwargs)
+                 scores, oof, oof_scores, X_trains, y_trains, x_vals, y_vals = ret_data
             else:
                 estimator.fit(X, y, **fit_kwargs)
             succeeded = True
@@ -85,31 +105,47 @@ class HyperModel:
             logger.error(track)
 
         if succeeded:
-            if scores is None:
-                scores = estimator.evaluate(X_eval, y_eval, metrics=metrics, **fit_kwargs)
-            reward = self._get_reward(scores, self.reward_metric)
 
             if model_file is None or len(model_file) == 0:
                 model_file = '%05d_%s.pkl' % (trial_no, space_sample.space_id)
             estimator.save(model_file)
 
-            elapsed = time.time() - start_time
+            elapsed = time.time() - start_time  # Notes: does not contains evaluation
+            trial = Trial(space_sample, trial_no, reward=None, elapsed=elapsed,
+                          model_file=model_file, succeeded=succeeded)
+            trial.context = self.context
 
-            trial = Trial(space_sample, trial_no, reward, elapsed, model_file, succeeded)
+            if self.searcher.kind() != const.SEARCHER_MOO:
+                if scores is None:
+                    scores = estimator.evaluate(X_eval, y_eval, metrics=metrics, **fit_kwargs)
+                reward = self._get_reward(scores, self.reward_metrics)
+            else:
+                if cv:
+                    assert x_vals is not None and y_vals is not None
+                    reward = [fn.evaluate_cv(trial, estimator, X_trains, y_trains,
+                                             x_vals, y_vals, X_test)
+                              for fn in self.searcher.objectives]
+                else:
+                    reward = [fn.evaluate(trial, estimator, X_eval, y_eval, X, y, X_test) for fn in self.searcher.objectives]
+
+            trial.reward = reward
             trial.iteration_scores = estimator.get_iteration_scores()
             trial.memo['scores'] = scores
+
             if oof is not None and self._is_memory_enough(oof):
                 trial.memo['oof'] = oof
             if oof_scores is not None:
                 trial.memo['oof_scores'] = oof_scores
 
             # improved = self.history.append(trial)
-
             self.searcher.update_result(space_sample, reward)
         else:
             elapsed = time.time() - start_time
-            trial = Trial(space_sample, trial_no, 0, elapsed, succeeded=succeeded)
-
+            if self.searcher.kind() == const.SEARCHER_MOO:
+                nan_scores = [None] * len(self.searcher.objectives)
+            else:
+                nan_scores = 0
+            trial = Trial(space_sample, trial_no, nan_scores, elapsed, succeeded=succeeded)
             if self.history is not None:
                 t = self.history.get_worst()
                 if t is not None:
@@ -123,7 +159,7 @@ class HyperModel:
         free = tb.memory_free() / tb.memory_total()
         return free > 0.618
 
-    def _get_reward(self, value, key=None):
+    def _get_reward(self, value: dict, keys: list = None):
         def cast_float(value):
             try:
                 fv = float(value)
@@ -131,20 +167,27 @@ class HyperModel:
             except TypeError:
                 return None
 
-        if key is None:
-            key = 'reward'
-        elif callable(key) and hasattr(key, '__name__'):
-            key = key.__name__
+        if keys is None:
+            keys = ['reward']
 
-        fv = cast_float(value)
-        if fv is not None:
-            reward = fv
-        elif isinstance(value, (dict, UserDict)) and key in value and cast_float(value[key]) is not None:
-            reward = cast_float(value[key])
-        else:
-            raise ValueError(
-                f'[value] should be a numeric or a dict which has a key named "{key}" whose value is a numeric.')
-        return reward
+        if not isinstance(value, (dict, UserDict)):
+            raise ValueError(f"[value] should be a dict but is {value} ")
+
+        rewards = []
+        for key in keys:
+            if callable(key) and hasattr(key, '__name__'):
+                key_name = key.__name__
+            else:
+                key_name = key
+            if key_name in value:
+                reward = cast_float(value[key_name])
+                if reward is not None:
+                    rewards.append(reward)
+                else:
+                    raise ValueError(
+                        f'[value] should be a numeric or a dict which has a key named "{key}" whose value is a numeric.')
+
+        return rewards
 
     def get_best_trial(self):
         return self.history.get_best()
@@ -153,7 +196,10 @@ class HyperModel:
     def best_reward(self):
         best = self.get_best_trial()
         if best is not None:
-            return best.reward
+            if isinstance(best, list):
+                return [t.reward for t in best]
+            else:
+                return best.reward
         else:
             return None
 
@@ -161,7 +207,10 @@ class HyperModel:
     def best_trial_no(self):
         best = self.get_best_trial()
         if best is not None:
-            return best.trial_no
+            if isinstance(best, list):
+                return [t.trial_no for t in best]
+            else:
+                return best.trial_no
         else:
             return None
 
@@ -174,13 +223,14 @@ class HyperModel:
     def _after_search(self, last_trial_no):
         pass
 
-    def search(self, X, y, X_eval, y_eval, cv=False, num_folds=3, max_trials=10, dataset_id=None, trial_store=None,
+    def search(self, X, y, X_eval, y_eval, X_test=None, cv=False, num_folds=3, max_trials=10, dataset_id=None, trial_store=None,
                **fit_kwargs):
         """
         :param X: Pandas or Dask DataFrame, feature data for training
         :param y: Pandas or Dask Series, target values for training
         :param X_eval: (Pandas or Dask DataFrame) or None, feature data for evaluation
         :param y_eval: (Pandas or Dask Series) or None, target values for evaluation
+        :param X_test: (Pandas or Dask Series) or None, target values for evaluation of indicators like PSI
         :param cv: Optional, int(default=False), If set to `true`, use cross-validation instead of evaluation set reward to guide the search process
         :param num_folds: Optional, int(default=3), Number of cross-validated folds, only valid when cv is true
         :param max_trials: Optional, int(default=10), The upper limit of the number of search trials, the search process stops when the number is exceeded
@@ -214,7 +264,7 @@ class HyperModel:
                 logger.warn(e)
 
         try:
-            trial_no = dispatcher.dispatch(self, X, y, X_eval, y_eval,
+            trial_no = dispatcher.dispatch(self, X, y, X_eval, y_eval, X_test,
                                            cv, num_folds, max_trials, dataset_id, trial_store,
                                            **fit_kwargs)
 
