@@ -13,7 +13,7 @@ class RandomSearcher(Searcher):
     def parallelizable(self):
         return True
 
-    def sample(self):
+    def sample(self, space_options=None):
         sample = self._sample_and_check(self._random_sample)
         return sample
 
