@@ -5,7 +5,7 @@
 from ._base import get_tool_box, register_toolbox, register_transformer, tb_transformer
 from .toolbox import ToolBox
 
-register_toolbox(ToolBox)
+register_toolbox(ToolBox, aliases=('default', 'pandas'))
 
 try:
     import dask.dataframe as dd
@@ -13,7 +13,7 @@ try:
     import dask_ml
     from .dask_ex import DaskToolBox
 
-    register_toolbox(DaskToolBox, 0)
+    register_toolbox(DaskToolBox, pos=0, aliases=('dask',))
     is_dask_installed = True
 except ImportError:
     # import traceback
@@ -26,7 +26,7 @@ try:
     import cuml
     from .cuml_ex import CumlToolBox
 
-    register_toolbox(CumlToolBox, 0)
+    register_toolbox(CumlToolBox, pos=0, aliases=('cuml', 'rapids'))
     is_cuml_installed = True
 except ImportError:
     # import traceback
