@@ -20,6 +20,20 @@ _KIND_PARQUET = 'parquet'
 _KIND_LIST = 'list'
 _KIND_NONE = 'none'
 
+_is_parquet_ready_flag = None
+
+
+def _is_parquet_ready(tb):
+    global _is_parquet_ready_flag
+    if _is_parquet_ready_flag is None:
+        try:
+            tb.parquet()
+            _is_parquet_ready_flag = True
+        except ImportError as e:
+            logger.warning(f'{e}, so cache strategy "{_STRATEGY_DATA}" is disabled.')
+            _is_parquet_ready_flag = False
+    return _is_parquet_ready_flag
+
 
 class SkipCache(Exception):
     pass
@@ -164,22 +178,32 @@ def decorate(fn, *, cache_dir, strategy,
                     c.on_apply(fn, cached_data, *args, **kwargs)
 
                 # restore attributes
+                original_attributes = {}
                 if attrs_to_restore is not None:
                     cached_attributes = meta.get('attributes', {})
                     for k in attrs_to_restore:
+                        original_attributes[k] = getattr(obj, k, None)
                         setattr(obj, k, cached_attributes.get(k))
 
                 if meta['strategy'] == _STRATEGY_DATA:
                     result = cached_data
+                    loaded = True
                 else:  # strategy==transform
-                    if isinstance(transformer, str):
-                        tfn = getattr(obj, transformer)
-                        assert callable(tfn)
-                        result = tfn(*args[1:], **kwargs)  # exclude args[0]==self
-                    elif callable(transformer):
-                        result = transformer(*args, **kwargs)
-
-                loaded = True
+                    try:
+                        if isinstance(transformer, str):
+                            tfn = getattr(obj, transformer)
+                            assert callable(tfn)
+                            result = tfn(*args[1:], **kwargs)  # exclude args[0]==self
+                        elif callable(transformer):
+                            result = transformer(*args, **kwargs)
+                        loaded = True
+                    except:
+                        # unexpected error, restore original attrs
+                        logger.warning(f'Failed to transform {type(obj).__name__}, '
+                                       f'the dependencies may have been changed, so try to disable cache.')
+                        for k, a in original_attributes.items():
+                            setattr(obj, k, a)
+                        loaded = False
         except SkipCache:
             pass
         except Exception as e:
@@ -195,6 +219,9 @@ def decorate(fn, *, cache_dir, strategy,
 
                 # store cache
                 cache_strategy = strategy if strategy is not None else cfg.cache_strategy
+                if cache_strategy == _STRATEGY_DATA and not _is_parquet_ready(tb):
+                    cache_strategy = _STRATEGY_TRANSFORM
+
                 if cache_strategy == _STRATEGY_TRANSFORM and (result is None or transformer is not None):
                     cache_data = None
                     meta = {'strategy': _STRATEGY_TRANSFORM}
@@ -241,7 +268,7 @@ def _store_cache(toolbox, cache_path, data, meta):
     elif isinstance(data, (list, tuple)):
         items = [f'_{i}' for i in range(len(data))]
         for d, i in zip(data, items):
-            _store_cache(f'{cache_path}{i}', d, meta)
+            _store_cache(toolbox, f'{cache_path}{i}', d, meta)
         meta.update({'kind': _KIND_LIST, 'items': items})
     else:
         pq = toolbox.parquet()
@@ -272,7 +299,7 @@ def _load_cache(toolbox, cache_path):
     if data_kind == _KIND_NONE:
         data = None
     elif data_kind == _KIND_LIST:
-        data = [_load_cache(f'{cache_path}{i}')[0] for i in items]
+        data = [_load_cache(toolbox, f'{cache_path}{i}')[0] for i in items]
     elif data_kind == _KIND_DEFAULT:  # pickle
         with fs.open(f'{cache_path}{items[0]}', 'rb') as f:
             data = pickle.load(f)
