@@ -4,6 +4,9 @@
 """
 
 from ..feature_generators import FeatureGenerationTransformer
+from ..feature_generators import is_feature_generator_ready as _is_feature_generator_ready
+
+is_feature_generator_ready = _is_feature_generator_ready
 
 
 class DaskFeatureGenerationTransformer(FeatureGenerationTransformer):
