@@ -25,7 +25,6 @@ from . import _data_hasher
 from . import _dataframe_mapper
 from . import _feature_generators
 from . import _metrics
-from . import _persistence
 from . import _transformers as tfs
 from .. import sklearn_ex as sk_ex
 
@@ -87,6 +86,31 @@ class DaskToolBox(ToolBox):
         client = DaskToolBox.default_client()
         return len(client.ncores()) if client else 0
 
+    @staticmethod
+    def dump_cluster_info(cluster=None, log_level=logging.INFO):
+        if not logger.is_enabled_for(log_level):
+            return
+
+        if cluster is None:
+            client = DaskToolBox.default_client()
+            if client is None:
+                logger.log(log_level, 'Not found dask default client.')
+                return
+            cluster = client.cluster
+
+        msgs = [f'Dask cluster: {cluster}', ]
+        try:
+            msgs.append(f'scheduler: {cluster.scheduler}')
+            msgs.append('workers:')
+            GB = 1024 ** 3
+            for i, wk in cluster.workers.items():
+                mem_limit = wk.memory_limit / GB
+                msgs.append(f'\t[{i}]: {wk}, mem: {mem_limit:.1f}GB')
+        except:
+            pass
+
+        logger.log(log_level, '\n'.join(msgs))
+
     @staticmethod
     def is_dask_dataframe(X):
         return isinstance(X, dd.DataFrame)
@@ -211,6 +235,7 @@ class DaskToolBox(ToolBox):
 
     @staticmethod
     def parquet():
+        from . import _persistence
         return _persistence.DaskParquetPersistence()
 
     # @staticmethod
@@ -795,9 +820,12 @@ _predefined_transformers = dict(
 
     # TfidfEncoder=sk_ex.TfidfEncoder,
     # DatetimeEncoder=sk_ex.DatetimeEncoder,
-    FeatureGenerationTransformer=_feature_generators.DaskFeatureGenerationTransformer,
+    # FeatureGenerationTransformer=_feature_generators.DaskFeatureGenerationTransformer,
     FeatureImportancesSelectionTransformer=sk_ex.FeatureImportancesSelectionTransformer,
 )
 
+if _feature_generators.is_feature_generator_ready:
+    _predefined_transformers['FeatureGenerationTransformer'] = _feature_generators.DaskFeatureGenerationTransformer
+
 for name, tf in _predefined_transformers.items():
     register_transformer(tf, name=name, dtypes=dd.DataFrame)
