@@ -29,7 +29,6 @@ from . import pseudo_labeling as pseudo_labeling_
 from . import sklearn_ex as sk_ex  # NOQA,  register customized transformer
 from ._base import ToolboxMeta, register_transformer
 from .cfg import TabularCfg as c
-from .persistence import ParquetPersistence
 
 try:
     import lightgbm
@@ -154,6 +153,7 @@ class ToolBox(metaclass=ToolboxMeta):
 
     @staticmethod
     def parquet():
+        from .persistence import ParquetPersistence
         return ParquetPersistence()
 
     @staticmethod
@@ -724,9 +724,12 @@ _predefined_transformers = dict(
     # TfidfEncoder=sk_ex.TfidfEncoder,
     # DatetimeEncoder=sk_ex.DatetimeEncoder,
 
-    FeatureGenerationTransformer=feature_generators_.FeatureGenerationTransformer,
+    # FeatureGenerationTransformer=feature_generators_.FeatureGenerationTransformer,
 )
 
+if feature_generators_.is_feature_generator_ready:
+    _predefined_transformers['FeatureGenerationTransformer'] = feature_generators_.FeatureGenerationTransformer
+
 for name, tf in _predefined_transformers.items():
     register_transformer(tf, name=name, dtypes=pd.DataFrame)
 
