@@ -141,6 +141,9 @@ class CustomizedLogger(_logging.Logger):
     def warning(self, msg, *args, **kwargs):
         self.log(WARN, msg, *args, **kwargs)
 
+    def warn(self, msg, *args, **kwargs):
+        self.log(WARN, msg, *args, **kwargs)
+
     def info(self, msg, *args, **kwargs):
         self.log(INFO, msg, *args, **kwargs)
 
@@ -193,6 +196,15 @@ class CustomizedLogger(_logging.Logger):
     def is_warning_enabled(self):
         return self.isEnabledFor(WARN)
 
+    def is_enabled_for(self, level):
+        return self.isEnabledFor(level)
+
+    def isEnabledFor(self, level):
+        if self.disabled:
+            return False
+
+        return level >= self.getEffectiveLevel()
+
 
 def get_logger(name):
     original_logger_class = _logging.getLoggerClass()
